@@ -1,5 +1,5 @@
 package AnyEvent::SlackRTM;
-$AnyEvent::SlackRTM::VERSION = '0.151800';
+$AnyEvent::SlackRTM::VERSION = '0.152660';
 use v5.14;
 
 # ABSTRACT: AnyEvent module for interacting with the Slack RTM API
@@ -212,38 +212,42 @@ AnyEvent::SlackRTM - AnyEvent module for interacting with the Slack RTM API
 
 =head1 VERSION
 
-version 0.151800
+version 0.152660
 
 =head1 SYNOPSIS
 
     use AnyEvent;
     use AnyEvent::SlackRTM;
-    
+
+    my $access_token = "<user or bot token>";
+    my $channel_id = "<channel/group/DM id>";
+
     my $cond = AnyEvent->condvar;
     my $rtm = AnyEvent::SlackRTM->new($access_token);
 
-    my $c = 1;
+    my $i = 1;
     my $keep_alive;
     my $counter;
     $rtm->on('hello' => sub { 
         print "Ready\n";
 
         $keep_alive = AnyEvent->timer(interval => 60, cb => sub {
+            print "Ping\n";
             $rtm->ping;
         });
 
         $counter = AnyEvent->timer(interval => 5, cb => sub {
+            print "Send\n";
             $rtm->send({
                 type => 'message',
-                text => $i++, 
+                channel => $channel_id,
+                text => "".$i++, 
             });
         });
     });
     $rtm->on('message' => sub { 
         my ($rtm, $message) = @_;
-        if ($message->{ok}) {
-            print "> ", $message->{text};
-        }
+        print "> $message->{text}\n";
     });
     $rtm->on('finish' => sub { 
         print "Done\n";
